@@ -28,8 +28,8 @@ from azureml.train.hyperdrive import HyperDriveConfig
 
 from health_azure.utils import (create_python_environment, create_run_recovery_id, _find_file,
                                 is_run_and_child_runs_completed, is_running_in_azure_ml, register_environment,
-                                run_duration_string_to_seconds,
-                                to_azure_friendly_string, RUN_CONTEXT, get_workspace)
+                                run_duration_string_to_seconds, to_azure_friendly_string, RUN_CONTEXT, get_workspace,
+                                PathOrString)
 from health_azure.datasets import (DatasetConfig, StrOrDatasetConfig, _input_dataset_key, _output_dataset_key,
                                    _replace_string_datasets)
 
@@ -45,8 +45,6 @@ RUN_RECOVERY_FILE = "most_recent_run.txt"
 SDK_NAME = "innereye"
 SDK_VERSION = "2.0"
 
-PathOrString = Union[Path, str]
-
 
 @dataclass
 class AzureRunInfo:
